@@ -3,11 +3,7 @@
 import sys
 import json
 import pytest
-from tuxsuite.cli.argparse import setup_parser
-from tuxsuite.cli.plan import (
-    handle_get,
-    handle_list,
-)
+import tuxsuite
 
 
 @pytest.fixture
@@ -539,55 +535,61 @@ def test_plan_handle_get(mocker, plan_json, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "plan", "get", "1tOhlD2nkPsRNNTMB5Lj09n1IVQ"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = plan_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
     # Test json out
+    mocker.resetall()
     monkeypatch.setattr(
         sys,
         "argv",
         ["tuxsuite", "plan", "get", "1tOhlD2nkPsRNNTMB5Lj09n1IVQ", "--json"],
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = plan_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
     # Test failure case when the response is not 200
     response.status_code = 500
     get_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_get(options, config)
+        tuxsuite.cli.main()
     assert get_req.call_count == 1
 
+    mocker.resetall()
+    response.status_code = 200
+    response._content = plan_json
+    get_req = mocker.patch("requests.get", return_value=response)
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["tuxsuite", "plan", "get", "1tOhlD2nkPsRNNTMB5Lj09n1IVQ", "--json"],
+    )
+    tuxsuite.cli.main()
+
 
 def test_plan_handle_list(mocker, plan_list_json, config, response, monkeypatch):
     monkeypatch.setattr(sys, "argv", ["tuxsuite", "plan", "list"])
     monkeypatch.setattr("sys.stdout.isatty", lambda: True)
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = plan_list_json
     list_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(SystemExit) as exit:
-        handle_list(options, config)
+        tuxsuite.cli.main()
     assert exit.value.code == 0
     assert list_req.call_count == 2
 
     # Test json out
     monkeypatch.setattr(sys, "argv", ["tuxsuite", "plan", "list", "--json"])
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = plan_list_json
     list_req = mocker.patch("requests.get", return_value=response)
-    handle_list(options, config)
+    tuxsuite.cli.main()
     assert exit.value.code == 0
     assert list_req.call_count == 1
 
@@ -595,39 +597,49 @@ def test_plan_handle_list(mocker, plan_list_json, config, response, monkeypatch)
     response.status_code = 500
     list_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        handle_list(options, config)
+        tuxsuite.cli.main()
     assert list_req.call_count == 1
 
+    mocker.resetall()
+    response.status_code = 200
+    response._content = plan_list_json
+    list_req = mocker.patch("requests.get", return_value=response)
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["tuxsuite", "plan", "list"],
+    )
+    with pytest.raises(SystemExit):
+        tuxsuite.cli.main()
+    assert list_req.call_count == 2
+
 
 def test_bake_plan_handle_get(mocker, bake_plan_json, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "plan", "get", "29EbSmPfjpbYQj8ZuaBpsiA8CbW"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = bake_plan_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
     # Test json out
+    mocker.resetall()
     monkeypatch.setattr(
         sys,
         "argv",
         ["tuxsuite", "plan", "get", "29EbSmPfjpbYQj8ZuaBpsiA8CbW", "--json"],
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = bake_plan_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
     # Test failure case when the response is not 200
     response.status_code = 500
     get_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_get(options, config)
+        tuxsuite.cli.main()
     assert get_req.call_count == 1
