@@ -2,11 +2,23 @@
 
 from itertools import chain
 
+import tuxsuite
 import tuxsuite.cli.colors as colors
 import tuxsuite.cli.icons as icons
 from tuxsuite.cli.models import Plan
 from tuxsuite.cli.requests import get
-from tuxsuite.cli.utils import LIMIT, datediff, fetch_next
+from tuxsuite.cli.common import common_options
+from tuxsuite.cli.utils import (
+    LIMIT,
+    error,
+    datediff,
+    fetch_next,
+    file_or_url,
+    format_result,
+    format_plan_result,
+    show_log,
+    wait_for_object,
+)
 
 import json
 import sys
@@ -91,7 +103,7 @@ def format_test(test):
     )
 
 
-def handle_get(options, config):
+def handle_get(options, _, config):
     ret = get(
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/plans/{options.uid}",
@@ -198,7 +210,7 @@ def handle_get(options, config):
     return 0
 
 
-def handle_list(options, config):
+def handle_list(options, _, config):
     url = f"/v1/groups/{config.group}/projects/{config.project}/plans"
     ret = get(config, url)
     if ret.status_code != 200:
@@ -227,12 +239,106 @@ def handle_list(options, config):
     return 0
 
 
+def handle_submit(cmdargs, _, config):
+    if cmdargs.git_head:
+        try:
+            cmdargs.git_repo, cmdargs.git_sha = tuxsuite.gitutils.get_git_head()
+        except Exception as e:
+            error(e)
+
+    try:
+        plan_config = tuxsuite.config.PlanConfig(
+            cmdargs.name, cmdargs.description, cmdargs.config[0], cmdargs.job_name
+        )
+
+        # setting respective plan type class obj (Kernel or Bake)
+        plan_type = plan_config.plan_type
+
+        if plan_config.schema_warning:
+            error(f"Invalid plan file: {plan_config.schema_warning}")
+
+        if not plan_config.plan:
+            error("Empty plan, skipping")
+            return
+        plan = tuxsuite.Plan(
+            plan_config,
+            git_repo=cmdargs.git_repo,
+            git_sha=cmdargs.git_sha,
+            git_ref=cmdargs.git_ref,
+        )
+    except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
+        error(e)
+
+    plan_type.plan_info(plan_config.name, plan_config.description)
+
+    try:
+        plan.submit()
+        print("Plan {}/plans/{}\n".format(plan.url, plan.plan))
+        print("uid: {}".format(plan.plan))
+    except tuxsuite.exceptions.BadRequest as e:
+        error(str(e))
+
+    result = True
+
+    if cmdargs.no_wait:
+        for build in plan.builds:
+            format_result(build.status)
+        for test in plan.tests:
+            format_result(test.status, plan.url + "/tests/{}".format(test.uid))
+    else:
+        result = wait_for_object(plan)
+        print(f"\nSummary: {plan.url}/plans/{plan.plan}")
+        for b in chain(plan.passing(), plan.warning(), plan.failing(), plan.errors()):
+            format_plan_result(b, plan._tests_wait_for(b.uid))
+
+    if cmdargs.json_out:
+        cmdargs.json_out.write(json.dumps(plan.status, sort_keys=True, indent=4))
+
+    if cmdargs.download:
+        for build in plan.builds:
+            tuxsuite.download.download(build, cmdargs.output_dir)
+    if cmdargs.show_logs:
+        for build in plan.builds:
+            show_log(build, cmdargs.download, cmdargs.output_dir)
+
+    if not result:
+        sys.exit(1)
+
+
 handlers = {
     "get": handle_get,
     "list": handle_list,
+    "submit": handle_submit,
 }
 
 
+def plan_cmd_options(sp):
+    sp.add_argument("--name", help="Set name")
+    sp.add_argument("--description", help="Set description")
+    sp.add_argument("--job-name", help="Job name")
+    sp.add_argument(
+        "--limit",
+        default=LIMIT,
+        help="Limit to LIMIT output. Used with [list]",
+    )
+    sp.add_argument(
+        "--json",
+        default=False,
+        action="store_true",
+        help="Show json output. Used with [get | list]",
+    )
+    sp.add_argument(
+        "-l",
+        "--local-manifest",
+        help=(
+            "Path to a local manifest file which will be used during repo sync. "
+            "This input is ignored if sources used is git_trees in the build "
+            "definition. Should be a valid XML. This option is only applicable in case of bake plan."
+        ),
+        type=file_or_url,
+    )
+
+
 def setup_parser(parser):
     # "plan get <uid>"
     p = parser.add_parser("get")
@@ -243,3 +349,17 @@ def setup_parser(parser):
     p = parser.add_parser("list")
     p.add_argument("--json", action="store_true")
     p.add_argument("--limit", type=int, default=LIMIT)
+
+    # "plan"
+    t = parser.add_parser("submit")
+    t.add_argument(
+        "config",
+        metavar="config",
+        nargs=1,
+        help="Plan config",
+        const=None,
+    )
+    plan_cmd_options(t)
+    common_options(t)
+
+    return sorted(parser._name_parser_map.keys())
